release_questions <- function() {
  c(
    "Did you update the version and date in 'man/sos4R-package.Rd' ?",
    "Did you update the pkgdown site with 'pkgdown::build_site()' ?",
    "Will you not forget to create a git tag as defined in the developer docs after the package is on CRAN ?"
  )
}
